RegexAcceleratorCapability

Struct RegexAcceleratorCapability 

pub struct RegexAcceleratorCapability {
    pub backend: &'static str,
    pub accelerator_class: RegexAcceleratorClass,
    pub supported: bool,
    pub device_signature: &'static str,
    pub rule_capacity: u32,
    pub stream_mode: RegexAcceleratorStreamMode,
    pub match_schema: RegexAcceleratorMatchSchema,
    pub unsupported_reason: &'static str,
}
Backend capability for hardware or software regex acceleration.

Fields

backend: &'static str

Backend id that owns this capability.

accelerator_class: RegexAcceleratorClass

Accelerator class.

supported: bool

True only when the backend can execute this accelerator class.

device_signature: &'static str

Device signature for supported accelerators.

rule_capacity: u32

Maximum rule count accepted by the accelerator.

stream_mode: RegexAcceleratorStreamMode

Stream mode accepted by the accelerator.

match_schema: RegexAcceleratorMatchSchema

Match schema emitted by the accelerator.

unsupported_reason: &'static str

Unsupported reason for fail-closed capability records.

Implementations

Source

impl RegexAcceleratorCapability

pub const fn unsupported( backend: &'static str, accelerator_class: RegexAcceleratorClass, unsupported_reason: &'static str, ) -> Self

Construct a fail-closed unsupported capability record.

pub const fn supported( backend: &'static str, accelerator_class: RegexAcceleratorClass, device_signature: &'static str, rule_capacity: u32, stream_mode: RegexAcceleratorStreamMode, match_schema: RegexAcceleratorMatchSchema, ) -> Self

Construct a supported accelerator capability record.

pub fn require_supported(self) -> Result<Self, BackendError>

Fail closed when a caller requires hardware regex acceleration.

Errors

Returns BackendError::UnsupportedFeature when this backend does not advertise the requested accelerator class.

pub const fn evidence(self, transfer_bytes: u64) -> RegexAcceleratorEvidence

Emit benchmark evidence for this regex accelerator capability.