Module device_work_queue

Module device_work_queue 

Backend-neutral device-side work queue planning. Backend-neutral device-side work queue planning for dependent dataflow execution.

Structs

DeviceWorkQueueBackpressurePlan
Device-side work queue plan with bounded resident drain windows.
DeviceWorkQueueExpansionProfile
Work queue profile where a resident queue should reserve device-side expansion headroom in addition to the initial frontier.
DeviceWorkQueuePlan
Device-side work queue execution plan.
DeviceWorkQueueProfile
Work queue workload profile.

Enums

DeviceWorkQueueDrainStrategy
Device-side work queue drain strategy.
DeviceWorkQueueError
Device work queue planning errors.
WorkQueueHostSync
Host synchronization policy for a device device-side work queue.

Functions

plan_device_work_queue
Plan a device-resident work queue for dependent dataflow execution.
plan_device_work_queue_backpressure
Plan a device-resident work queue plus bounded device-side drain windows.
plan_device_work_queue_with_expansion
Plan a device-resident work queue that preserves initial-frontier capacity and uses remaining queue budget for device-side expansion headroom.