pub struct OpLocation {
pub op_id: Cow<'static, str>,
pub operand_idx: Option<u32>,
pub attr_name: Option<Cow<'static, str>>,
}Expand description
Location of a diagnostic inside a Program.
Fields
op_id: Cow<'static, str>The op identifier, for example "math.add".
operand_idx: Option<u32>Zero-based operand index, if the diagnostic is about a specific operand.
attr_name: Option<Cow<'static, str>>Attribute name, if the diagnostic is about a specific attribute.
Implementations
Sourceimpl OpLocation
impl OpLocation