pub enum GraphCaptureEditAction {
Replay,
Update,
Recapture,
}Expand description
Backend-neutral action selected for a scan graph-capture edit.
Variants
Replay
Reuse the captured graph without parameter update.
Update
Update graph parameters or copied input bytes without recapturing topology.
Recapture
Re-record the graph because topology, pointer shape, or code changed.
Implementations