pub enum GraphCaptureEditStability {
GraphStable,
GraphBreaking,
}Expand description
Graph-topology stability after applying one scan edit.
Variants
GraphStable
Captured graph topology and pointer table shape remain valid.
GraphBreaking
Captured graph topology or pointer table shape is invalidated.
Implementations