pub enum MultiQueryExecutionError {
DuplicateQuery {
query: u32,
},
ZeroGraphHash {
query: u32,
},
ZeroTraversalKey {
query: u32,
},
ZeroGraphUploadBytes {
query: u32,
},
GraphUploadBytesMismatch {
graph_layout_hash: u64,
expected_bytes: u64,
actual_bytes: u64,
query: u32,
},
ZeroBudget,
ByteCountOverflow {
field: &'static str,
},
OverBudget {
graph_layout_hash: u64,
traversal_key: u64,
required_bytes: u64,
budget_bytes: u64,
},
StorageReserveFailed {
field: &'static str,
requested: usize,
message: String,
},
InternalInvariant {
message: &'static str,
},
}Expand description
multi-query planning errors.
Variants
DuplicateQuery
Duplicate query id.
ZeroGraphHash
Query needs a non-zero graph hash.
ZeroTraversalKey
Query needs a non-zero traversal compatibility key.
ZeroGraphUploadBytes
Query must report non-zero resident graph upload bytes.
GraphUploadBytesMismatch
Equal graph hashes must agree on the resident graph byte width.
Fields
ZeroBudget
Explicit device budget cannot be zero.
ByteCountOverflow
Byte arithmetic overflowed.
OverBudget
A grouped resident envelope exceeds the explicit device budget.
Fields
StorageReserveFailed
Planner storage could not be reserved.
Fields
InternalInvariant
Planner state violated an internal construction invariant.