pub struct OutputLayout {
pub full_size: usize,
pub read_size: usize,
pub copy_offset: usize,
pub copy_size: usize,
pub trim_start: usize,
}Expand description
Output readback layout derived from a program’s declared output range.
Fields
full_size: usizeFull output buffer byte size allocated on the GPU.
read_size: usizeConsumer-visible byte count returned from dispatch.
copy_offset: usizeAligned source offset copied from the GPU output buffer.
copy_size: usizeAligned staging-buffer byte size.
trim_start: usizeOffset within the staging buffer where the requested range starts.