pub struct ResultCompactionPlan {
pub compact_records: Vec<CompactResultRecord>,
pub direct_slots: Vec<u32>,
pub full_capacity_bytes: u64,
pub compact_bytes: u64,
pub direct_bytes: u64,
pub selected_readback_bytes: u64,
pub avoided_readback_bytes: u64,
pub avoided_readback_basis_points: u32,
}Expand description
Compact result readback plan.
Fields
compact_records: Vec<CompactResultRecord>Records copied into the compact slab.
direct_slots: Vec<u32>Output slots left as direct readback ranges.
full_capacity_bytes: u64Total allocated/readback capacity across all output slots.
compact_bytes: u64Total compact slab bytes.
direct_bytes: u64Total direct readback bytes.
selected_readback_bytes: u64Total bytes actually selected for readback after compaction planning.
avoided_readback_bytes: u64Bytes avoided compared with reading full output capacities.
avoided_readback_basis_points: u32Avoided readback as floor basis points of full capacity.