pub struct RoutingTable { /* private fields */ }Expand description
Per-call-site profile used by routing decisions.
Implementations
Sourceimpl RoutingTable
impl RoutingTable
Sourcepub fn observe_sort_u32(
&self,
call_site: Cow<'_, str>,
values: &[u32],
) -> Result<SortBackend, String>
pub fn observe_sort_u32( &self, call_site: Cow<'_, str>, values: &[u32], ) -> Result<SortBackend, String>
Record one call-site observation and return the selected backend.
Errors
Returns an error if the routing table mutex is poisoned.
Sourcepub fn distribution(&self, call_site: &str) -> Option<Distribution>
pub fn distribution(&self, call_site: &str) -> Option<Distribution>
Return the last observed distribution for a call site.